package de.intevation.artifactdatabase.state;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

/**
 * The StateEngine stores all states for each Artifact.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class StateEngine {

    /** The logger used in this class. */
    private static Logger logger = Logger.getLogger(StateEngine.class);

    /**
     * A map that contains the states of the artifacts. The key of this map is
     * the name of an artifact, its value is a list of all states the artifact
     * can reach.
     */
    protected Map<String, List> states;


    /**
     * The default constructor.
     */
    public StateEngine() {
        states = new HashMap<String, List>();
    }


    /**
     * Add new states for a specific artifact.
     *
     * @param artifact The name of the artifact.
     * @param states A list of states that the artifact can reach.
     *
     * @return true, if the states were added, otherwise false.
     */
    public boolean addStates(String artifact, List states) {
        List tmp = this.states.get(artifact);

        if (tmp != null) {
            logger.info(
                "States for the artifact '" + artifact + "' already stored.");

            return false;
        }

        logger.debug("Add new states for the artifact '" + artifact + "'");
        return this.states.put(artifact, states) != null;
    }


    /**
     * Returns the state list of an artifact specified by its name.
     *
     * @param artifact The name of the artifact.
     *
     * @return the list of states of this artifact or <i>null</i> if no states
     * are existing for this <i>artifact</i>.
     */
    public List<State> getStates(String artifact) {
        return states.get(artifact);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
